#include <math.h>
#include "tb.h"


float FastInversePlanck(float L, float lambda, float lambda5)
/*
!C*****************************************************************************
!Description:
	Optimized function to invert Planck function.

!Input Parameters:
	L		radiance (W/m^2/str/micron)

	lambda		wavelength (microns)

	lambda5		wavelength raised to the 5th power (microns^5);
			redundant but precomputed for speed

!Output Parameters:
	Returns blackbody temperature (kelvins).

!Revision History:
	Original poorly-optimized version August 1996, L. Giglio.
	Rewritten October 2008 to eliminate call to pow5() function.
!END***************************************************************************
*/
{
	float num, denom;
	const float C1 = 1.19107e8F;	/* W micron^4 / m^2 sr */
	const float C2 = 1.43883e4F;	/* micron K */

	num = C2 / lambda;
	denom = logf(1.0F + C1/(L * lambda5));

	return num / denom;
}

